package Foo;
our $VERSION = '0.01';


sub hello {"hello"}
sub world {"world"}

1;
